@@ -3,7 +3,7 @@ package Mojolicious::Plugin::Web::Auth;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Mojo::Base 'Mojolicious::Plugin';
 
@@ -96,9 +96,24 @@ Mojolicious::Plugin::Web::Auth - Authentication plugin for Mojolicious
   # /auth/twitter/callback
   # /auth/facebook/callback
 
+  # If, for example, your Instagram app needs more permissions than the
+  # defaults allow:
+
+  # Mojolicious
+  $self->plugin('Web::Auth',
+      module      => 'Instagram',
+      key         => 'Instagram consumer key',
+      secret      => 'Instagram consumer secret',
+      on_finished => sub {
+          my ( $c, $access_token, $access_secret ) = @_;
+          ...
+      },
+      authorize_url => 'https://api.instagram.com/oauth/authorize?scope=public_content',
+  );
+
 =head1 DESCRIPTION
 
-L<Mojolicious::Plugin::Web::Auth> is authentication plugin for L<Mojolicious>.
+L<Mojolicious::Plugin::Web::Auth> is an authentication plugin for L<Mojolicious>.
 
 =head1 METHODS
 
@@ -116,15 +131,15 @@ Dropbox, Facebook, Github, Google, Instagram, Twitter.
 
 =head2 C<key>
 
-consumer key
+Consumer key.
 
 =head2 C<secret>
 
-consumer secret
+Consumer secret.
 
 =head2 C<scope>
 
-optional. OAuth 2.0 only.
+Optional: OAuth 2.0 only.
 
   # Facebook
   plugin 'Web::Auth',
@@ -139,7 +154,7 @@ optional. OAuth 2.0 only.
 
 =head2 C<validate_state>
 
-optinal. OAuth 2.0 only. default value is 1, see L<http://tools.ietf.org/html/rfc6819#section-5.3.5>
+Optional: OAuth 2.0 only. Default value is 1, see L<http://tools.ietf.org/html/rfc6819#section-5.3.5>.
 
 
 =head2 C<on_finished>
@@ -154,7 +169,7 @@ optinal. OAuth 2.0 only. default value is 1, see L<http://tools.ietf.org/html/rf
           ...
       };
 
-This is a callback when authentication was finished.
+This callback is run when authentication was finished.
 
 =head3 arguments
 
@@ -188,13 +203,17 @@ Facebook, Github, Google, Instagram, etc.
 
 =item user_info ( enabled 'user_info' )
 
+=item rest of the response data (HASHREF)
+
+id_token, expires, refresh_token, etc.
+
 =back
 
 =back
 
 =head2 C<on_error>
 
-This is a callback when authentication was errored.
+This is a callback is run on authentication errors.
 
 =head1 AUTHOR
 
@@ -218,6 +237,10 @@ Many thanks to the contributors for their work.
 
 =item levonet@github
 
+=item oalders@github
+
+=item ccakes@github
+
 =back
 
 =head1 COPYRIGHT
