@@ -7,6 +7,6 @@ has authorize_url    => 'https://www.facebook.com/dialog/oauth';
 has access_token_url => 'https://graph.facebook.com/oauth/access_token';
 has user_info_url    => 'https://graph.facebook.com/me';
 
-has moniker => sub {'facebook'};
+sub moniker {'facebook'};
 
 1;
